@@ -120,6 +120,7 @@ class MemoryBankConfig(BaseModel):
     """Memory-Bank configuration."""
     
     projects: Dict[str, MemoryBankProject] = Field(default_factory=dict)
+    mcp_servers: Dict[str, str] = Field(default_factory=dict)  # server_name -> project_name mapping
     active_project: Optional[str] = None
 
 
@@ -133,7 +134,7 @@ class GlobalConfig(BaseModel):
     hil: HILConfig = Field(default_factory=HILConfig)
     llm: LLMConfig = Field(default_factory=LLMConfig)
     memory_bank: MemoryBankConfig = Field(default_factory=MemoryBankConfig)
-    version: str = "0.1.0"
+    version: str = "0.1.4"
     debug: bool = False
     
     @field_validator('openai_api_key')
@@ -1015,39 +1016,18 @@ def setup_project_interactive(update_mode=False):
     # Individual setup choices
     console.print("\n🎯 Configuration Setup:")
     
-    # Voice command setup
-    setup_voice = Confirm.ask("Setup /voice slash command?", default=True)
-    
-    # HIL rules setup  
-    setup_hil_rules = Confirm.ask("Add init-hil-rules command for CLAUDE.md updates?", default=False)
-    
     # MCP setup
     setup_mcp = Confirm.ask("Setup HIL MCP integration (ask-human tool)?", default=True)
     
     # Create .helpers directory for HIL
     helpers_dir = project_dir / ".helpers"
-    if (setup_voice or setup_mcp) and not helpers_dir.exists():
+    if setup_mcp and not helpers_dir.exists():
         try:
             setup_helpers_directory(project_dir)
             console.print("✅ Created .helpers directory for HIL")
         except Exception as e:
             console.print(f"⚠️  Failed to create .helpers directory: {e}")
     
-    # Apply selections
-    if setup_voice:
-        try:
-            setup_voice_command_only(project_dir)
-            console.print("✅ Setup /voice command")
-        except Exception as e:
-            console.print(f"⚠️  Failed to setup voice command: {e}")
-    
-    if setup_hil_rules:
-        try:
-            setup_init_hil_rules_command(project_dir)
-            console.print("✅ Added init-hil-rules command")
-        except Exception as e:
-            console.print(f"⚠️  Failed to add init-hil-rules: {e}")
-    
     # MCP registration
     mcp_registered = False
     if setup_mcp:
@@ -1069,8 +1049,18 @@ def setup_project_interactive(update_mode=False):
         )
         if setup_mcp_timeout:
             try:
-                configure_mcp_timeout()
-                console.print("✅ Configured MCP timeout for HIL")
+                # Use simplified timeout configuration (10 minutes default)
+                import subprocess
+                timeout_ms = 600000  # 10 minutes default for HIL
+                result = subprocess.run(
+                    ['claude', 'config', 'set', 'MCP_TOOL_TIMEOUT', str(timeout_ms)],
+                    capture_output=True,
+                    text=True
+                )
+                if result.returncode == 0:
+                    console.print(f"✅ Configured MCP timeout to {timeout_ms}ms (10 minutes)")
+                else:
+                    raise Exception(f"Failed to set MCP timeout: {result.stderr or result.stdout}")
             except Exception as e:
                 console.print(f"⚠️  Failed to configure MCP timeout: {e}")
                 console.print("    You can configure manually with:")
@@ -1102,11 +1092,9 @@ def setup_project_interactive(update_mode=False):
     
     step_num = 2 if (setup_mcp and not mcp_registered) else 1
     
-    if setup_voice or setup_mcp:
+    if setup_mcp:
         next_steps.append(f"{step_num}. Start HIL listener: claude-helpers listen")
         step_num += 1
-        
-    if setup_voice:
         next_steps.append(f"{step_num}. Use /voice in Claude Code for voice instructions")
         step_num += 1
         
